==> igloo_0_1_8.zip: igloo_0_1_8/igloo/language/1/barnraiser_01/blg_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['hdr_blog_entry'] = 						"blog entry";
$lang['hdr_recent'] = 							"recent blogs";
$lang['hdr_blogs'] = 							"blog entries";
$lang['hdr_blog'] = 							"blog";
$lang['hdr_my_network_blogs'] = 				"latest blog entries from my network";
$lang['hdr_options'] =							"blog options";
$lang['hdr_blog_author'] = 						"author";


// HREF
$lang['href_network_blog'] = 					"view their blog";
$lang['href_view_node'] = 						"latest from the group";
$lang['href_view_network'] = 					"latest from my network";
$lang['href_my_blog'] = 						"my blog";
$lang['href_marked'] = 							"marked blog entries";
$lang['href_list_blog'] = 						"list entries for this blog";
$lang['href_add_blog'] = 						"add a blog entry to my blog";


// ERROR
$lang['err_no_blog'] = 							"Sorry, there are no blogs available.";


// BODY
$lang['txt_published_to'] = 					"Published to";
$lang['txt_tag'] = 								"tags";
$lang['txt_options'] = 							"options";
$lang['txt_view'] = 							"view";
$lang['txt_intro_node'] = 						"Listed are the last SYS_KEYWORD_NUMBER (max) blog entries that have been published by a member of this group.";
$lang['txt_intro_network'] = 					"Listed are the last SYS_KEYWORD_NUMBER (max) blog entries that have been published by a person in your network.";
$lang['txt_outro_network'] = 					"The following people in your network have not published a blog entry within the last SYS_KEYWORD_NUMBER.";


// BREADCRUMB (texts that appears when you role over the breadcrumb navigation)
$lang['nav_breadcrumb'] = 						"blog";

?>

==> igloo_0_1_9.zip: igloo_0_1_9/igloo/language/1/barnraiser_01/blg_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['hdr_blog_entry'] = 						"blog entry";
$lang['hdr_recent'] = 							"recent blogs";
$lang['hdr_blogs'] = 							"blog entries";
$lang['hdr_blog'] = 							"blog";
$lang['hdr_my_network_blogs'] = 				"latest blog entries from my network";
$lang['hdr_options'] =							"blog options";
$lang['hdr_blog_author'] = 						"author";


// HREF
$lang['href_network_blog'] = 					"view their blog";
$lang['href_view_node'] = 						"latest from the group";
$lang['href_view_network'] = 					"latest from my network";
$lang['href_my_blog'] = 						"my blog";
$lang['href_marked'] = 							"marked blog entries";
$lang['href_tipped'] = 							"tipped blog entries";
$lang['href_list_blog'] = 						"list entries for this blog";
$lang['href_add_blog'] = 						"add a blog entry to my blog";


// ERROR
$lang['err_no_blog'] = 							"Sorry, there are no blogs available.";


// BODY
$lang['txt_published_to'] = 					"Published to";
$lang['txt_tag'] = 								"tags";
$lang['txt_options'] = 							"options";
$lang['txt_view'] = 							"view";
$lang['txt_intro_node'] = 						"Listed are the last SYS_KEYWORD_NUMBER (max) blog entries that have been published by a member of this group.";
$lang['txt_intro_network'] = 					"Listed are the last SYS_KEYWORD_NUMBER (max) blog entries that have been published by a person in your network.";
$lang['txt_outro_network'] = 					"The following people in your network have not published a blog entry within the last SYS_KEYWORD_NUMBER.";
$lang['txt_intro_marked'] = 					"You have bookmarked the following items for reading. You can manage your bookmarks under 'Me', 'marks &amp; tips'.";
$lang['txt_intro_tipped'] = 					"Your network have recommended (tipped) the following items for reading. You can manage your recommendations to your network under 'Me', 'marks &amp; tips'.";


// BREADCRUMB (texts that appears when you role over the breadcrumb navigation)
$lang['nav_breadcrumb'] = 						"blog";

?>
